@@ -2,17 +2,17 @@
 
 import os
 import sys
+import operator
 import subprocess
 
-PY2 = sys.version_info.major == 2
+PY2 = (sys.version_info.major == 2)
 
 
 if PY2:
     string_classes = (str, unicode)  # needed individually for sublassing
     text_type = unicode
 
-    def iteritems(d):
-        return d.iteritems()
+    iteritems = operator.methodcaller('iteritems')
 
     def makedirs(name, mode=0o777, exist_ok=False):
         try:
@@ -27,6 +27,24 @@ if PY2:
         if flush:
             sys.stderr.flush()
 
+    def Popen_stderr_devnull(*args, **kwargs):  # noqa: N802
+        with open(os.devnull, 'w') as f:
+            return subprocess.Popen(*args, stderr=f, **kwargs)
+
+    class CalledProcessError(subprocess.CalledProcessError):
+
+        def __init__(self, returncode, cmd, output=None, stderr=None):
+            super(CalledProcessError, self).__init__(returncode, cmd, output)
+            self.stderr = stderr
+
+        @property
+        def stdout(self):
+            return self.output
+
+        @stdout.setter
+        def stdout(self, value):  # pragma: no cover
+            self.output = value
+
 
 else:
     string_classes = (str,)
@@ -45,22 +63,7 @@ else:
         if flush:
             sys.stderr.flush()
 
+    def Popen_stderr_devnull(*args, **kwargs):  # noqa: N802
+        return subprocess.Popen(*args, stderr=subprocess.DEVNULL, **kwargs)
 
-if sys.version_info < (3, 5):
-    class CalledProcessError(subprocess.CalledProcessError):
-
-        def __init__(self, returncode, cmd, output=None, stderr=None):
-            super(CalledProcessError, self).__init__(returncode, cmd, output)
-            self.stderr = stderr
-
-        @property
-        def stdout(self):
-            return self.output
-
-        @stdout.setter
-        def stdout(self, value):  # pragma: no cover
-            self.output = value
-
-
-else:
     CalledProcessError = subprocess.CalledProcessError
